import tables
import tstables
import datetime
import numpy

def create_ts(self,where,name,description=None,title="",filters=None,
    expectedrows_per_partition=10000,chunkshape=None,
    byteorder=None,createparents=False):

    # Check the Description to make sure the first col is "timestamp" with type Int64
    for k in description.columns.keys():
        if description.columns[k]._v_pos == 0:
            first_col_name = k

    if first_col_name != 'timestamp':
        raise AttributeError("first column must be called 'timestamp' and have type Int64")

    if description.columns[first_col_name].dtype != numpy.dtype('int64'):
        raise AttributeError("first column must be called 'timestamp' and have type Int64")

    # The parent node of the time series
    tsnode = self.create_group(where,name,title,filters,createparents)

    try:
        # Decorate with TsTables attributes
        tsnode._v_attrs._TS_TABLES_CLASS='TIMESERIES'
        tsnode._v_attrs._TS_TABLES_VERSION='0.0.1'

        ts = tstables.TsTable(self,tsnode,description,title,filters,expectedrows_per_partition,
            chunkshape,byteorder)

        # Need to create one partition to "save" the time series. This creates a new table to persist
        # the table description
        ts._TsTable__create_partition(datetime.datetime.utcnow().date())
    except:
        # Make sure that the group is deleted if an exception is raised
        self.remove_node(tsnode,recursive=True)
        raise

    return ts






import tables
import tstables
import datetime

def timeseries_repr(self):
	"""Return a detailed string representation of the group or time series.

	Examples
	--------

	::

		>>> f = tables.open_file('data/test.h5')
		>>> f.root.group0
		/group0 (Group) 'First Group'
		  children := ['tuple1' (Table), 'group1' (Group)]

	::

		>>> f = tables.open_file('data/test_timeseries.h5')
		>>> f.root.timeseries0
		/timeseries0 (Group/Timeseries) 'A group that is also a time series'

	"""
	try:
		tstables_class = self._v_attrs._TS_TABLES_CLASS

		# Additional representation (maybe min timestamp, max timestamp) goes here
		# Don't include all of the children here!

		return "%s" % str(self)

	except AttributeError:
		rep = [
			'%r (%s)' % (childname, child.__class__.__name__)
			for (childname, child) in self._v_children.iteritems()
		]
		childlist = '[%s]' % (', '.join(rep))

		return "%s\n  children := %s" % (str(self), childlist)



def timeseries_str(self):
	"""Return a short string representation of the group or time series.

	Examples
	--------

	::

		>>> f=tables.open_file('data/test.h5')
		>>> print(f.root.group0)
		/group0 (Group) 'First Group'

	::
		>>> f = tables.open_file('data/test_timeseries.h5')
		>>> f.root.timeseries0
		/timeseries0 (Group/Timeseries) 'A group that is also a time series'

	"""

	try:
		tstables_class = self._v_attrs._TS_TABLES_CLASS
		classname = "%s/Timeseries" % self.__class__.__name__
	except AttributeError:
		classname = self.__class__.__name__

	pathname = self._v_pathname
	title = self._v_title
	return "%s (%s) %r" % (pathname, classname, title)

def get_timeseries(self):
	try:
		tstables_class = self._v_attrs._TS_TABLES_CLASS
	except AttributeError:
		return None

	ts_table = tstables.TsTable(self._v_file,self,None)

	# Need to determine the description, title, filters, expectedrows_per_partition,
	# chunkshape, byteorder
	ts_data = ts_table._TsTable__fetch_first_table()
	ts_table.table_description = ts_data.description
	ts_table.table_title = ts_data.title
	ts_table.table_filters = ts_data.filters
	ts_table.table_chunkshape = ts_data.chunkshape
	ts_table.table_byteorder = ts_data.byteorder
	ts_table.table_expectedrows_per_partition = ts_data.attrs._TS_TABLES_EXPECTEDROWS_PER_PARTITION

	return ts_table